==> huaweicloudsdkprojectman-3.0.84-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/delete_iteration_v4_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteIterationV4Request:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'iteration_id': 'int'
    }

    attribute_map = {
        'project_id': 'project_id',
        'iteration_id': 'iteration_id'
    }

    def __init__(self, project_id=None, iteration_id=None):
        """DeleteIterationV4Request - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._iteration_id = None
        self.discriminator = None

        self.project_id = project_id
        self.iteration_id = iteration_id

    @property
    def project_id(self):
        """Gets the project_id of this DeleteIterationV4Request.

        devcloud的项目id

        :return: The project_id of this DeleteIterationV4Request.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DeleteIterationV4Request.

        devcloud的项目id

        :param project_id: The project_id of this DeleteIterationV4Request.
        :type: str
        """
        self._project_id = project_id

    @property
    def iteration_id(self):
        """Gets the iteration_id of this DeleteIterationV4Request.

        迭代id

        :return: The iteration_id of this DeleteIterationV4Request.
        :rtype: int
        """
        return self._iteration_id

    @iteration_id.setter
    def iteration_id(self, iteration_id):
        """Sets the iteration_id of this DeleteIterationV4Request.

        迭代id

        :param iteration_id: The iteration_id of this DeleteIterationV4Request.
        :type: int
        """
        self._iteration_id = iteration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteIterationV4Request):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.86-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/delete_iteration_v4_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteIterationV4Request:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'iteration_id': 'int'
    }

    attribute_map = {
        'project_id': 'project_id',
        'iteration_id': 'iteration_id'
    }

    def __init__(self, project_id=None, iteration_id=None):
        """DeleteIterationV4Request

        The model defined in huaweicloud sdk

        :param project_id: devcloud的项目id
        :type project_id: str
        :param iteration_id: 迭代id
        :type iteration_id: int
        """
        
        

        self._project_id = None
        self._iteration_id = None
        self.discriminator = None

        self.project_id = project_id
        self.iteration_id = iteration_id

    @property
    def project_id(self):
        """Gets the project_id of this DeleteIterationV4Request.

        devcloud的项目id

        :return: The project_id of this DeleteIterationV4Request.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DeleteIterationV4Request.

        devcloud的项目id

        :param project_id: The project_id of this DeleteIterationV4Request.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def iteration_id(self):
        """Gets the iteration_id of this DeleteIterationV4Request.

        迭代id

        :return: The iteration_id of this DeleteIterationV4Request.
        :rtype: int
        """
        return self._iteration_id

    @iteration_id.setter
    def iteration_id(self, iteration_id):
        """Sets the iteration_id of this DeleteIterationV4Request.

        迭代id

        :param iteration_id: The iteration_id of this DeleteIterationV4Request.
        :type iteration_id: int
        """
        self._iteration_id = iteration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteIterationV4Request):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
